/** @file exam_inifcns_nstdsums.h
 *
 *  Comparison data for the test of polylogarithms. */

/*
 *  GiNaC Copyright (C) 1999-2017 Johannes Gutenberg University Mainz, Germany
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

string polylogdata[] = {
"1",
"1",
"1/5",
"0.2110037754397047726111851",
"1",
"2",
"1/5",
"0.01154815698320587834851847",
"1",
"3",
"1/5",
"0.0005671604269057464369336278",
"2",
"1",
"1/5",
"0.2053241957333103187906279",
"2",
"2",
"1/5",
"0.005496394299313416180783147",
"2",
"3",
"1/5",
"0.0001775366905181881667796781",
"3",
"1",
"1/5",
"0.2026055828608337918073629",
"3",
"2",
"1/5",
"0.002660800832970401591293284",
"3",
"3",
"1/5",
"0.00005648589591441390456209617",
"1",
"1",
"1",
"1.644934066848226436472415",
"1",
"2",
"1",
"1.202056903159594285399738",
"1",
"3",
"1",
"1.082323233711138191516004",
"2",
"1",
"1",
"1.202056903159594285399738",
"2",
"2",
"1",
"0.2705808084277845478790009",
"2",
"3",
"1",
"0.09655115998944373446564553",
"3",
"1",
"1",
"1.082323233711138191516004",
"3",
"2",
"1",
"0.09655115998944373446564553",
"3",
"3",
"1",
"0.01748985316901140442593445",
"1",
"1",
"7/5",
"2.319073036309661140597949 - 1.057058706706129136511424*I",
"1",
"2",
"7/5",
"0.400128217350851507240443 - 2.117870033958637239292535*I",
"1",
"3",
"7/5",
"-1.306942067751837699697874 - 0.9582504865992154234972912*I",
"2",
"1",
"7/5",
"1.89888115124088465887076 - 0.1778354536426690011875291*I",
"2",
"2",
"7/5",
"0.6147866145423269326988408 - 0.450346061295973806397063*I",
"2",
"3",
"7/5",
"0.02364313457019212818533082 - 0.3957649083518131684924005*I",
"3",
"1",
"7/5",
"1.598181449557006942439464 - 0.01994556427923228904747691*I",
"3",
"2",
"7/5",
"0.255166723694153893894118 - 0.05744406976402892180206415*I",
"3",
"3",
"7/5",
"0.06183658590899077899926822 - 0.06413563191670074072577209*I",
"1",
"1",
"3",
"2.320180423313098396406194 - 3.451392295223202661433821*I",
"1",
"2",
"3",
"-3.283054973314733671722888 - 2.121348992833316537253189*I",
"1",
"3",
"3",
"-1.308956801609585468303169 + 2.735768992719806273982232*I",
"2",
"1",
"3",
"3.74212259424073163537853 - 1.8958709942733213939055*I",
"2",
"2",
"3",
"-0.480510635231494396450204 - 2.302538950265844976567974*I",
"2",
"3",
"3",
"-1.340253408976406939530336 + 0.2712277258998196470831479*I",
"3",
"1",
"3",
"3.748509891070099635577777 - 0.6942757240126994329423387*I",
"3",
"2",
"3",
"0.4861841788146436502060471 - 1.108719697043548174143929*I",
"3",
"3",
"3",
"-0.4434283619758922093239171 - 0.2953184763564641050133537*I",
"1",
"1",
"1/5 + (3*I)/10",
"0.1817624136255447449184249 + 0.3300021664312349365005342*I",
"1",
"2",
"1/5 + (3*I)/10",
"-0.02127060891668272269977564 + 0.02960990860383052619662807*I",
"1",
"3",
"1/5 + (3*I)/10",
"-0.00309623659733713567217526 - 0.0006081451141979055410326925*I",
"2",
"1",
"1/5 + (3*I)/10",
"0.1918812948232063923430136 + 0.3150961462895829294435211*I",
"2",
"2",
"1/5 + (3*I)/10",
"-0.009100341083225460545023609 + 0.01505275697697292299710076*I",
"2",
"3",
"1/5 + (3*I)/10",
"-0.001002045705125824985735953 - 0.0000931525145668252525455795*I",
"3",
"1",
"1/5 + (3*I)/10",
"0.1962643925058113082072159 + 0.3075543063564529215440445*I",
"3",
"2",
"1/5 + (3*I)/10",
"-0.004053799099843583119296245 + 0.007560021359667667770852211*I",
"3",
"3",
"1/5 + (3*I)/10",
"-0.0003240792138489462062797713 - 5.830899924898618321929032E-6*I",
"1",
"1",
"1 + (3*I)/10",
"1.261005636400337930308118 + 0.7156828245191393467143763*I",
"1",
"2",
"1 + (3*I)/10",
"0.1998831977949975418578584 + 0.6244483919686713779224936*I",
"1",
"3",
"1 + (3*I)/10",
"-0.1364622100637802947057075 + 0.2406763129716348319993979*I",
"2",
"1",
"1 + (3*I)/10",
"1.139163376813876647799732 + 0.4441977154715400716583975*I",
"2",
"2",
"1 + (3*I)/10",
"0.1436177344738862689488375 + 0.1974318055898878411698054*I",
"2",
"3",
"1 + (3*I)/10",
"-0.004631384159507411802648499 + 0.0641990837118411118030704*I",
"3",
"1",
"1 + (3*I)/10",
"1.066719273153223255872187 + 0.3561898809884808259030033*I",
"3",
"2",
"1 + (3*I)/10",
"0.0710206968588785102864562 + 0.06946535138235496111746761*I",
"3",
"3",
"1 + (3*I)/10",
"0.003394713278779414104889703 + 0.01572567802823333948945599*I",
"1",
"1",
"7/5 + (3*I)/10",
"1.746328220125828463357781 + 1.293912877394488172676492*I",
"1",
"2",
"7/5 + (3*I)/10",
"-0.1705237731249613771154105 + 1.410448047723192221781715*I",
"1",
"3",
"7/5 + (3*I)/10",
"-0.7993328986491419154562113 + 0.2240473689385119401472374*I",
"2",
"1",
"7/5 + (3*I)/10",
"1.695022640104322001454814 + 0.6311207314778676822437355*I",
"2",
"2",
"7/5 + (3*I)/10",
"0.2500128026974790456104579 + 0.5085989943285245053960182*I",
"2",
"3",
"7/5 + (3*I)/10",
"-0.1148557150224370365078302 + 0.1915495333472110502058456*I",
"3",
"1",
"7/5 + (3*I)/10",
"1.551224385087703633744372 + 0.4096736133572680716788505*I",
"3",
"2",
"7/5 + (3*I)/10",
"0.1610086739116176049491314 + 0.1573532373869367492158508*I",
"3",
"3",
"7/5 + (3*I)/10",
"0.00008355670074290449954321072 + 0.05802311653447669691333529*I",
"1",
"1",
"3 + (3*I)/10",
"2.011020920616701077455812 + 3.397072105237087682189828*I",
"1",
"2",
"3 + (3*I)/10",
"-3.091859759069532002434627 + 1.666118629453408661739254*I",
"1",
"3",
"3 + (3*I)/10",
"-0.8878527778981529594861016 - 2.434364480366253327812887*I",
"2",
"1",
"3 + (3*I)/10",
"3.411586707187776500840283 + 2.128627570334239892859671*I",
"2",
"2",
"3 + (3*I)/10",
"-0.6847253205832210157136079 + 1.994290299048607560691603*I",
"2",
"3",
"3 + (3*I)/10",
"-1.088233543788019837240912 - 0.3929749894500587756908124*I",
"3",
"1",
"3 + (3*I)/10",
"3.565487383713819583850992 + 1.060767984969548945285053*I",
"3",
"2",
"3 + (3*I)/10",
"0.2692762029815113608515477 + 1.060947988767443679766785*I",
"3",
"3",
"3 + (3*I)/10",
"-0.4159967816412745726855725 + 0.172858247942700149618331*I",
"1",
"1",
"1/5 - (7*I)/5",
"-0.2168382064320079699732261 - 1.290878454583813741543234*I",
"1",
"2",
"1/5 - (7*I)/5",
"-0.3451669563336866625816169 + 0.1957774036164392101927372*I",
"1",
"3",
"1/5 - (7*I)/5",
"0.08214427234994582908698386 + 0.06449056709956809894940379*I",
"2",
"1",
"1/5 - (7*I)/5",
"-0.03042144217050376321269406 - 1.378042181254097119943019*I",
"2",
"2",
"1/5 - (7*I)/5",
"-0.2122053137898958092005104 + 0.06004832979925179307301476*I",
"2",
"3",
"1/5 - (7*I)/5",
"0.02299484687792200922486322 + 0.03281780472569582817172184*I",
"3",
"1",
"1/5 - (7*I)/5",
"0.07954758404396723589806321 - 1.402590109062933871392952*I",
"3",
"2",
"1/5 - (7*I)/5",
"-0.1166624266816937993242638 + 0.01219776187261535273200268*I",
"3",
"3",
"1/5 - (7*I)/5",
"0.005446850058125122681940759 + 0.01368445926518218498435562*I",
"1",
"1",
"1 - (7*I)/5",
"0.3229223427783080464168482 - 1.740744589472007676760007*I",
"1",
"2",
"1 - (7*I)/5",
"-0.7462501471409844475821687 - 0.06809527240892149178849717*I",
"1",
"3",
"1 - (7*I)/5",
"0.01726448925633681090502602 + 0.2746453959884960147929753*I",
"2",
"1",
"1 - (7*I)/5",
"0.6992465770229889358880579 - 1.66024142746129637527113*I",
"2",
"2",
"1 - (7*I)/5",
"-0.360932620346732658930704 - 0.1766337145573970952978008*I",
"2",
"3",
"1 - (7*I)/5",
"-0.03837478847084106478326429 + 0.09480468232038559943747127*I",
"3",
"1",
"1 - (7*I)/5",
"0.8732997135886229894915555 - 1.555949977360525360725989*I",
"3",
"2",
"1 - (7*I)/5",
"-0.1553598469745823402728118 - 0.1341718446987175963404485*I",
"3",
"3",
"1 - (7*I)/5",
"-0.02428660616580131371668603 + 0.02676895982537889521216678*I",
"1",
"1",
"7/5 - (7*I)/5",
"0.5553932412307858310125187 - 2.038950110146658192024572*I",
"1",
"2",
"7/5 - (7*I)/5",
"-1.042554222290367637550906 - 0.21436451215527849991702*I",
"1",
"3",
"7/5 - (7*I)/5",
"-0.0314419508370015033194055 + 0.4613268808592085414432077*I",
"2",
"1",
"7/5 - (7*I)/5",
"1.071931369421352221757937 - 1.853170643333167599178124*I",
"2",
"2",
"7/5 - (7*I)/5",
"-0.4628797620304465221346583 - 0.3422886294340223997935778*I",
"2",
"3",
"7/5 - (7*I)/5",
"-0.098587457456488904995548 + 0.144684644948941321119675*I",
"3",
"1",
"7/5 - (7*I)/5",
"1.286793410334209264901226 - 1.657513826017920212261891*I",
"3",
"2",
"7/5 - (7*I)/5",
"-0.1711141231913325258586839 - 0.2375876206470994404554137*I",
"3",
"3",
"7/5 - (7*I)/5",
"-0.05299201267886299861483348 + 0.03258270024606783452944098*I",
"1",
"1",
"3 - (7*I)/5",
"1.007938136309594236518511 - 3.386967910892347904114225*I",
"1",
"2",
"3 - (7*I)/5",
"-2.682309699233097296322462 - 0.2859940229969369808426482*I",
"1",
"3",
"3 - (7*I)/5",
"0.2765591454514408934814353 + 1.697149375282038684500721*I",
"2",
"1",
"3 - (7*I)/5",
"2.405733557488370170927602 - 2.951504413417675817858886*I",
"2",
"2",
"3 - (7*I)/5",
"-1.272036042194284768991475 - 1.103934330435370660107263*I",
"2",
"3",
"3 - (7*I)/5",
"-0.4131756886737842334273695 + 0.6696371310771923308835628*I",
"3",
"1",
"3 - (7*I)/5",
"2.972854638910796659727421 - 2.283639962584069752219147*I",
"3",
"2",
"3 - (7*I)/5",
"-0.3478855022054033507183165 - 0.861985838577452633146836*I",
"3",
"3",
"3 - (7*I)/5",
"-0.2931771313199542816919608 + 0.1294389736359485891156582*I",
"1",
"1",
"-1/5",
"-0.1908001377775356190369132",
"1",
"2",
"-1/5",
"0.008826841601567502361076978",
"1",
"3",
"-1/5",
"-0.0003602784749049460977504445",
"2",
"1",
"-1/5",
"-0.1952735929310542759464553",
"2",
"2",
"-1/5",
"0.004596651976424285002647089",
"2",
"3",
"-1/5",
"-0.0001263988435607805606549976",
"3",
"1",
"-1/5",
"-0.1975929828245178964051594",
"3",
"2",
"-1/5",
"0.002362344648329100774111073",
"3",
"3",
"-1/5",
"-0.00004379738606960102828759222",
"1",
"1",
"-1",
"-0.8224670334241132182362076",
"1",
"2",
"-1",
"0.1502571128949492856749673",
"1",
"3",
"-1",
"-0.02375236632261848595145358",
"2",
"1",
"-1",
"-0.9015426773696957140498036",
"2",
"2",
"-1",
"0.08778567156865530203659329",
"2",
"3",
"-1",
"-0.009601568443129832539131915",
"3",
"1",
"-1",
"-0.9470328294972459175765032",
"3",
"2",
"-1",
"0.04893639704996906336074275",
"3",
"3",
"-1",
"-0.003716769548592781918107256",
"1",
"1",
"-7/5",
"-1.08557795634712507555489",
"1",
"2",
"-7/5",
"0.2535957124764954803911381",
"1",
"3",
"-7/5",
"-0.05093174821838708462957568",
"2",
"1",
"-7/5",
"-1.22082452959280891549602",
"2",
"2",
"-7/5",
"0.1543815262398468671292177",
"2",
"3",
"-7/5",
"-0.02163750431283488956581388",
"3",
"1",
"-7/5",
"-1.301610824979171412102903",
"3",
"2",
"-7/5",
"0.08870564296364697150488985",
"3",
"3",
"-7/5",
"-0.00871772008813535940594319",
"1",
"1",
"-3",
"-1.939375420766708953077272",
"1",
"2",
"-3",
"0.7401475948629590886006417",
"1",
"3",
"-3",
"-0.2388642027836877889744444",
"2",
"1",
"-3",
"-2.348790554584076557805871",
"2",
"2",
"-3",
"0.5052321953754768909798843",
"2",
"3",
"-3",
"-0.1162576824693628931275475",
"3",
"1",
"-3",
"-2.620634701909763503399941",
"3",
"2",
"-3",
"0.3167617872532832638027071",
"3",
"3",
"-3",
"-0.05239918743720934590666285",
"1",
"1",
"-1/5 + (3*I)/10",
"-0.2081375660560016691180584 + 0.271539573686964633554782*I",
"1",
"2",
"-1/5 + (3*I)/10",
"-0.006200306433802806244546582 - 0.02755725248800315290955911*I",
"1",
"3",
"-1/5 + (3*I)/10",
"0.001818502491789777318252704 + 0.0009559436708325564438468345*I",
"2",
"1",
"-1/5 + (3*I)/10",
"-0.2047344007413153491087881 + 0.2854777299439535793275641*I",
"2",
"2",
"-1/5 + (3*I)/10",
"-0.004038610781088847480082351 - 0.01424503726588138737660998*I",
"2",
"3",
"-1/5 + (3*I)/10",
"0.0006652711668165765971408173 + 0.0002934227620804844427033155*I",
"3",
"1",
"-1/5 + (3*I)/10",
"-0.2026042284782455939272071 + 0.2926491978893533527001885*I",
"3",
"2",
"-1/5 + (3*I)/10",
"-0.002359494267385617865817285 - 0.007265538502225720435935446*I",
"3",
"3",
"-1/5 + (3*I)/10",
"0.0002369749599853333168387193 + 0.00008996209578666453955023634*I",
"1",
"1",
"-1 + (3*I)/10",
"-0.8311055859228710527021677 + 0.2073360436500721692194286*I",
"1",
"2",
"-1 + (3*I)/10",
"0.1455401550055480603645109 - 0.07267193472183533522977989*I",
"1",
"3",
"-1 + (3*I)/10",
"-0.02083627378227584305092946 + 0.01672552997230549172122192*I",
"2",
"1",
"-1 + (3*I)/10",
"-0.9073419079834184114447723 + 0.2464470365463464571609752*I",
"2",
"2",
"-1 + (3*I)/10",
"0.08376539924730892731282976 - 0.045405632659608804479704*I",
"2",
"3",
"-1 + (3*I)/10",
"-0.008166356600680041447558106 + 0.007121736557247280229634791*I",
"3",
"1",
"-1 + (3*I)/10",
"-0.9505841828121466238694754 + 0.2703335409661860138524939*I",
"3",
"2",
"-1 + (3*I)/10",
"0.04613568575261606910948221 - 0.02649226808945891578525802*I",
"3",
"3",
"-1 + (3*I)/10",
"-0.003076901614047636533503766 + 0.002865298661915431865476615*I",
"1",
"1",
"-7/5 + (3*I)/10",
"-1.092255930565444290873424 + 0.1872027187528210004638889*I",
"1",
"2",
"-7/5 + (3*I)/10",
"0.2507030731562681070931293 - 0.08246441686535181031534989*I",
"1",
"3",
"-7/5 + (3*I)/10",
"-0.04836674848597030757206477 + 0.02405657879061358055417332*I",
"2",
"1",
"-7/5 + (3*I)/10",
"-1.225636208433777830980876 + 0.2324146448166787965024073*I",
"2",
"2",
"-7/5 + (3*I)/10",
"0.1514213464117155295505894 - 0.0545567849979022294452559*I",
"2",
"3",
"-7/5 + (3*I)/10",
"-0.0202370471983203649736778 + 0.01093086270702111560507259*I",
"3",
"1",
"-7/5 + (3*I)/10",
"-1.304711331517666307849045 + 0.2615065000784211344732767*I",
"3",
"2",
"-7/5 + (3*I)/10",
"0.08643429001568645798547407 - 0.03319415276445834766819764*I",
"3",
"3",
"-7/5 + (3*I)/10",
"-0.008043667164485079944230409 + 0.004632973425413277692348251*I",
"1",
"1",
"-3 + (3*I)/10",
"-1.942551546682366732836815 + 0.1385113577988186448308648*I",
"1",
"2",
"-3 + (3*I)/10",
"0.7397577908011303261178357 - 0.09615281833074637614887741*I",
"1",
"3",
"-3 + (3*I)/10",
"-0.2374827198203849556295063 + 0.0444555740229337148101881*I",
"2",
"1",
"-3 + (3*I)/10",
"-2.351553051208418782513253 + 0.1938593564424504357210138*I",
"2",
"2",
"-3 + (3*I)/10",
"0.5041313667167973137464733 - 0.07407505829641226394882236*I",
"2",
"3",
"-3 + (3*I)/10",
"-0.1152322031792111205458574 + 0.02390870793562240883880077*I",
"3",
"1",
"-3 + (3*I)/10",
"-2.622680415628126177913255 + 0.2348348146600913992121239*I",
"3",
"2",
"-3 + (3*I)/10",
"0.3155888092146481843947796 - 0.05056466301637635689587639*I",
"3",
"3",
"-3 + (3*I)/10",
"-0.05178609922359599756648275 + 0.01163245402672827483911887*I",
"1",
"1",
"-1/5 - (7*I)/5",
"-0.4881017391704919698644137 - 1.135412444586148945381494*I",
"1",
"2",
"-1/5 - (7*I)/5",
"-0.1971656061670911303773324 + 0.2830489021195984451067474*I",
"1",
"3",
"-1/5 - (7*I)/5",
"0.08327801417600615009074186 + 0.001704672880135397041794967*I",
"2",
"1",
"-1/5 - (7*I)/5",
"-0.3756042722949367843163278 - 1.276742330773723026583351*I",
"2",
"2",
"-1/5 - (7*I)/5",
"-0.1425543292510341605176513 + 0.1371689738219304202869984*I",
"2",
"3",
"-1/5 - (7*I)/5",
"0.03200226354857854335390015 + 0.008484129594088192242994194*I",
"3",
"1",
"-1/5 - (7*I)/5",
"-0.2989787245379329728481531 - 1.343931693249974927004725*I",
"3",
"2",
"-1/5 - (7*I)/5",
"-0.08768206779922630788149317 + 0.06312126273316916646478938*I",
"3",
"3",
"-1/5 - (7*I)/5",
"0.0113129385853053859543144 + 0.005457767175425329169967248*I",
"1",
"1",
"-1 - (7*I)/5",
"-0.9908545815305659001669631 - 0.9174238158763567154670398*I",
"1",
"2",
"-1 - (7*I)/5",
"0.07158866870852659804528872 + 0.3848933976593964916851421*I",
"1",
"3",
"-1 - (7*I)/5",
"0.04104500496256023042828098 - 0.08830136129011211863744217*I",
"2",
"1",
"-1 - (7*I)/5",
"-1.019925023746657680786921 - 1.124595552357277967090879*I",
"2",
"2",
"-1 - (7*I)/5",
"0.01094531629637096576106268 + 0.2391481544336993271405549*I",
"2",
"3",
"-1 - (7*I)/5",
"0.02357505184715364176504762 - 0.03439362632057322142473194*I",
"3",
"1",
"-1 - (7*I)/5",
"-1.021499207085205316693109 - 1.249910330188513806434707*I",
"3",
"2",
"-1 - (7*I)/5",
"-0.007882374362414223985282586 + 0.1373380367744643419880309*I",
"3",
"3",
"-1 - (7*I)/5",
"0.01131346671394310166327279 - 0.01249777055577485543723401*I",
"1",
"1",
"-7/5 - (7*I)/5",
"-1.219555621006325199438054 - 0.8393745907107140203389614*I",
"1",
"2",
"-7/5 - (7*I)/5",
"0.2032677355467648046702975 + 0.4125491216559647513257176*I",
"1",
"3",
"-7/5 - (7*I)/5",
"0.004251513439720678915835991 - 0.1220075446358158947006697*I",
"2",
"1",
"-7/5 - (7*I)/5",
"-1.320619838306054643300648 - 1.065892704705797834077402*I",
"2",
"2",
"-7/5 - (7*I)/5",
"0.09622408133639172555129377 + 0.2731105405145626022369582*I",
"2",
"3",
"-7/5 - (7*I)/5",
"0.00951544830063435766599513 - 0.05325436913012775421685466*I",
"3",
"1",
"-7/5 - (7*I)/5",
"-1.367189039383852145686536 - 1.211304952533601220820439*I",
"3",
"2",
"-7/5 - (7*I)/5",
"0.04191859292832405903506325 + 0.1649890654426153562624566*I",
"3",
"3",
"-7/5 - (7*I)/5",
"0.00650742909654574627250664 - 0.02154883251720226822552705*I",
"1",
"1",
"-3 - (7*I)/5",
"-2.006259543508918559280738 - 0.6354714738426061956495618*I",
"1",
"2",
"-3 - (7*I)/5",
"0.7334357233719708844030849 + 0.4542190668645801440306082*I",
"1",
"3",
"-3 - (7*I)/5",
"-0.209564820779042583816149 - 0.2124232415316877464738453*I",
"2",
"1",
"-3 - (7*I)/5",
"-2.407691021662430819635011 - 0.8973481314410885673384452*I",
"2",
"2",
"-3 - (7*I)/5",
"0.4825248461079058792674081 + 0.3512296398074683129878294*I",
"2",
"3",
"-3 - (7*I)/5",
"-0.09410081400094719179439828 - 0.1137427094521510277377264*I",
"3",
"1",
"-3 - (7*I)/5",
"-2.664589576762315164690982 - 1.091708967972938645662153*I",
"3",
"2",
"-3 - (7*I)/5",
"0.2919106864477335633096292 + 0.2398489133615198556169296*I",
"3",
"3",
"-3 - (7*I)/5",
"-0.03903027674986962142416068 - 0.05495539307612344158160473*I",
"-999"};
